# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from apeman.dal.tsdb import tsdb_pb2 as apeman_dot_dal_dot_tsdb_dot_tsdb__pb2


class TsdbServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.createDatafeed = channel.unary_unary(
                '/com.apeman.dal.TsdbService/createDatafeed',
                request_serializer=apeman_dot_dal_dot_tsdb_dot_tsdb__pb2.CreateDatafeedRequest.SerializeToString,
                response_deserializer=apeman_dot_dal_dot_tsdb_dot_tsdb__pb2.CreateDatafeedResponse.FromString,
                )
        self.deleteDatafeed = channel.unary_unary(
                '/com.apeman.dal.TsdbService/deleteDatafeed',
                request_serializer=apeman_dot_dal_dot_tsdb_dot_tsdb__pb2.DeleteDatafeedRequest.SerializeToString,
                response_deserializer=apeman_dot_dal_dot_tsdb_dot_tsdb__pb2.DeleteDatafeedResponse.FromString,
                )
        self.getDatafeed = channel.unary_unary(
                '/com.apeman.dal.TsdbService/getDatafeed',
                request_serializer=apeman_dot_dal_dot_tsdb_dot_tsdb__pb2.GetDatafeedRequest.SerializeToString,
                response_deserializer=apeman_dot_dal_dot_tsdb_dot_tsdb__pb2.GetDatafeedResponse.FromString,
                )
        self.listDatafeed = channel.unary_unary(
                '/com.apeman.dal.TsdbService/listDatafeed',
                request_serializer=apeman_dot_dal_dot_tsdb_dot_tsdb__pb2.ListDatafeedRequest.SerializeToString,
                response_deserializer=apeman_dot_dal_dot_tsdb_dot_tsdb__pb2.ListDatafeedResponse.FromString,
                )
        self.putData = channel.unary_unary(
                '/com.apeman.dal.TsdbService/putData',
                request_serializer=apeman_dot_dal_dot_tsdb_dot_tsdb__pb2.PutDataRequest.SerializeToString,
                response_deserializer=apeman_dot_dal_dot_tsdb_dot_tsdb__pb2.PutDataResponse.FromString,
                )
        self.getData = channel.unary_unary(
                '/com.apeman.dal.TsdbService/getData',
                request_serializer=apeman_dot_dal_dot_tsdb_dot_tsdb__pb2.GetDataRequest.SerializeToString,
                response_deserializer=apeman_dot_dal_dot_tsdb_dot_tsdb__pb2.GetDataResponse.FromString,
                )
        self.getDataAsJson = channel.unary_unary(
                '/com.apeman.dal.TsdbService/getDataAsJson',
                request_serializer=apeman_dot_dal_dot_tsdb_dot_tsdb__pb2.GetDataRequest.SerializeToString,
                response_deserializer=apeman_dot_dal_dot_tsdb_dot_tsdb__pb2.ResultAsJson.FromString,
                )


class TsdbServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def createDatafeed(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def deleteDatafeed(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def getDatafeed(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def listDatafeed(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def putData(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def getData(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def getDataAsJson(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_TsdbServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'createDatafeed': grpc.unary_unary_rpc_method_handler(
                    servicer.createDatafeed,
                    request_deserializer=apeman_dot_dal_dot_tsdb_dot_tsdb__pb2.CreateDatafeedRequest.FromString,
                    response_serializer=apeman_dot_dal_dot_tsdb_dot_tsdb__pb2.CreateDatafeedResponse.SerializeToString,
            ),
            'deleteDatafeed': grpc.unary_unary_rpc_method_handler(
                    servicer.deleteDatafeed,
                    request_deserializer=apeman_dot_dal_dot_tsdb_dot_tsdb__pb2.DeleteDatafeedRequest.FromString,
                    response_serializer=apeman_dot_dal_dot_tsdb_dot_tsdb__pb2.DeleteDatafeedResponse.SerializeToString,
            ),
            'getDatafeed': grpc.unary_unary_rpc_method_handler(
                    servicer.getDatafeed,
                    request_deserializer=apeman_dot_dal_dot_tsdb_dot_tsdb__pb2.GetDatafeedRequest.FromString,
                    response_serializer=apeman_dot_dal_dot_tsdb_dot_tsdb__pb2.GetDatafeedResponse.SerializeToString,
            ),
            'listDatafeed': grpc.unary_unary_rpc_method_handler(
                    servicer.listDatafeed,
                    request_deserializer=apeman_dot_dal_dot_tsdb_dot_tsdb__pb2.ListDatafeedRequest.FromString,
                    response_serializer=apeman_dot_dal_dot_tsdb_dot_tsdb__pb2.ListDatafeedResponse.SerializeToString,
            ),
            'putData': grpc.unary_unary_rpc_method_handler(
                    servicer.putData,
                    request_deserializer=apeman_dot_dal_dot_tsdb_dot_tsdb__pb2.PutDataRequest.FromString,
                    response_serializer=apeman_dot_dal_dot_tsdb_dot_tsdb__pb2.PutDataResponse.SerializeToString,
            ),
            'getData': grpc.unary_unary_rpc_method_handler(
                    servicer.getData,
                    request_deserializer=apeman_dot_dal_dot_tsdb_dot_tsdb__pb2.GetDataRequest.FromString,
                    response_serializer=apeman_dot_dal_dot_tsdb_dot_tsdb__pb2.GetDataResponse.SerializeToString,
            ),
            'getDataAsJson': grpc.unary_unary_rpc_method_handler(
                    servicer.getDataAsJson,
                    request_deserializer=apeman_dot_dal_dot_tsdb_dot_tsdb__pb2.GetDataRequest.FromString,
                    response_serializer=apeman_dot_dal_dot_tsdb_dot_tsdb__pb2.ResultAsJson.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'com.apeman.dal.TsdbService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class TsdbService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def createDatafeed(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/com.apeman.dal.TsdbService/createDatafeed',
            apeman_dot_dal_dot_tsdb_dot_tsdb__pb2.CreateDatafeedRequest.SerializeToString,
            apeman_dot_dal_dot_tsdb_dot_tsdb__pb2.CreateDatafeedResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def deleteDatafeed(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/com.apeman.dal.TsdbService/deleteDatafeed',
            apeman_dot_dal_dot_tsdb_dot_tsdb__pb2.DeleteDatafeedRequest.SerializeToString,
            apeman_dot_dal_dot_tsdb_dot_tsdb__pb2.DeleteDatafeedResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def getDatafeed(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/com.apeman.dal.TsdbService/getDatafeed',
            apeman_dot_dal_dot_tsdb_dot_tsdb__pb2.GetDatafeedRequest.SerializeToString,
            apeman_dot_dal_dot_tsdb_dot_tsdb__pb2.GetDatafeedResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def listDatafeed(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/com.apeman.dal.TsdbService/listDatafeed',
            apeman_dot_dal_dot_tsdb_dot_tsdb__pb2.ListDatafeedRequest.SerializeToString,
            apeman_dot_dal_dot_tsdb_dot_tsdb__pb2.ListDatafeedResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def putData(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/com.apeman.dal.TsdbService/putData',
            apeman_dot_dal_dot_tsdb_dot_tsdb__pb2.PutDataRequest.SerializeToString,
            apeman_dot_dal_dot_tsdb_dot_tsdb__pb2.PutDataResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def getData(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/com.apeman.dal.TsdbService/getData',
            apeman_dot_dal_dot_tsdb_dot_tsdb__pb2.GetDataRequest.SerializeToString,
            apeman_dot_dal_dot_tsdb_dot_tsdb__pb2.GetDataResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def getDataAsJson(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/com.apeman.dal.TsdbService/getDataAsJson',
            apeman_dot_dal_dot_tsdb_dot_tsdb__pb2.GetDataRequest.SerializeToString,
            apeman_dot_dal_dot_tsdb_dot_tsdb__pb2.ResultAsJson.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



from apeman.dal.tsdb import DataAmount
from apeman.dal.tsdb import DataType
from apeman.dal.tsdb import tsdb_pb2


class ColumnDefinitionBuilder(object):

    def __init__(self):
        self.name: str = None
        self.data_type: DataType = None
        self.limit: int = None
        self.non_null: bool = None

    def set_name(self, name: str = None):
        self.name = name
        return self

    def set_type(self, data_type: DataType):
        self.data_type = data_type
        return self

    def set_limit(self, limit: int = None):
        self.limit = limit
        return self

    def set_non_null(self, non_null: bool = None):
        self.non_null = non_null
        return self

    def build(self) -> tsdb_pb2.ColumnDefinition:
        data_type = DataTypeBuilder().set_type(self.data_type).build()
        ret = tsdb_pb2.ColumnDefinition(name=self.name, type=data_type, limit=self.limit,
                                        nonNull=self.non_null)
        return ret


class CreateDatafeedRequestBuilder(object):

    def __init__(self):
        self.name: str = None
        self.tag: [tsdb_pb2.ColumnDefinition] = []
        self.field: [tsdb_pb2.ColumnDefinition] = []
        self.unique_key: [tsdb_pb2.UniqueKey] = []
        self.data_amount: DataAmount = None

    def set_name(self, name: str = None):
        self.name = name
        return self

    def add_tag(self, tag: tsdb_pb2.ColumnDefinition = None):
        self.tag.append(tag)
        return self

    def add_field(self, field: tsdb_pb2.ColumnDefinition = None):
        self.field.append(field)
        return self

    def add_unique_key(self, unique_key: tsdb_pb2.UniqueKey = None):
        self.unique_key.append(unique_key)
        return self

    def set_data_amount(self, data_amount: DataAmount = None):
        self.data_amount = data_amount
        return self

    def build(self) -> tsdb_pb2.CreateDatafeedRequest:
        data_amount = DataAmountBuilder().set_data_amount(self.data_amount).build()
        ret = tsdb_pb2.CreateDatafeedRequest(name=self.name, tag=self.tag, field=self.field,
                                             uniqueKey=self.unique_key, dataAmount=data_amount)
        return ret


class DataAmountBuilder(object):

    def __init__(self):
        self.data_amount: DataAmount = DataAmount.UNKNOWN.value

    def set_data_amount(self, data_amount: DataAmount = DataAmount.UNKNOWN):
        self.data_amount = data_amount.value
        return self

    def build(self) -> tsdb_pb2.DataAmount:
        ret = tsdb_pb2.DataAmount.Value(self.data_amount)
        return ret


class DataTypeBuilder(object):

    def __init__(self):
        self.data_type: DataType = DataType.UNKNOWN.value

    def set_type(self, data_type: DataType = DataType.UNKNOWN):
        self.data_type = data_type.value
        return self

    def build(self) -> tsdb_pb2.DataType:
        ret = tsdb_pb2.DataType.Value(self.data_type)
        return ret


class UniqueKeyBuilder(object):
    def __init__(self):
        self.name: [str] = []

    def __reset__(self):
        self.name = []

    def add(self, name: str = None):
        self.name.append(name)
        return self

    def build(self) -> tsdb_pb2.UniqueKey:
        ret = tsdb_pb2.UniqueKey(name=self.name)
        return ret


class ValBuilder(object):

    def __init__(self):
        self.s = None
        self.i64 = None
        self.i32 = None
        self.d = None
        self.f = None
        self.b = None
        self.ts = None

    def __reset__(self):
        self.s = None
        self.i64 = None
        self.i32 = None
        self.d = None
        self.f = None
        self.b = None
        self.ts = None

    def set_s(self, s: str = None):
        self.s = s
        return self

    def set_i64(self, i64: int = None):
        self.__reset__()
        self.i64 = i64
        return self

    def set_i32(self, i32: int = None):
        self.__reset__()
        self.i32 = i32
        return self

    def set_d(self, d: float = None):
        self.__reset__()
        self.d = d
        return self

    def set_f(self, f: float = None):
        self.__reset__()
        self.f = f
        return self

    def set_b(self, b: bool = None):
        self.__reset__()
        self.b = b
        return self

    def set_ts(self, epoch_in_millis: int = None):
        self.__reset__()
        self.ts = tsdb_pb2.Timestamp(epochInMillis=epoch_in_millis)
        return self

    def build(self) -> tsdb_pb2.Val:
        ret = tsdb_pb2.Val(s=self.s, i64=self.i64, i32=self.i32, d=self.d, f=self.f, b=self.b, ts=self.ts)
        return ret


class TimestampBuilder(object):

    def __init__(self):
        self.epoch_in_millis: int = None

    def set_epoch_in_millis(self, epoch_in_millis: int = None):
        self.epoch_in_millis = epoch_in_millis
        return self

    def build(self) -> tsdb_pb2.Timestamp:
        ret = tsdb_pb2.Timestamp(epochInMillis=self.epoch_in_millis)
        return ret


class TupleBuilder(object):

    def __init__(self):
        self.val: [tsdb_pb2.Val] = []

    def add_val(self, val: tsdb_pb2.Val):
        self.val.append(val)
        return self

    def build(self):
        ret = tsdb_pb2.Tuple(cell=self.val)
        return ret


class ColumnMetaBuilder(object):

    def __init__(self):
        self.data_type: DataType = None
        self.name: str = None

    def set_name(self, name: str):
        self.name = name
        return self

    def set_data_type(self, data_type: DataType):
        self.data_type = data_type
        return self

    def build(self):
        data_type_builder = DataTypeBuilder()
        data_type = data_type_builder.set_type(self.data_type).build()
        ret = tsdb_pb2.ColumnMeta(name=self.name, type=data_type)
        return ret


class TabularDataBuilder(object):

    def __init__(self):
        self.column: [tsdb_pb2.ColumnMeta] = []
        self.tuple: [tsdb_pb2.Tuple] = []

    def add_column(self, column: tsdb_pb2.ColumnMeta):
        self.column.append(column)
        return self

    def add_tuple(self, t: tsdb_pb2.Tuple = None):
        self.tuple.append(t)
        return self

    def build(self):
        ret = tsdb_pb2.TabularData(column=self.column, tuple=self.tuple)
        return ret


class PutDataRequestBuilder(object):

    def __init__(self):
        self.datafeed: str = None
        self.tabular_data: tsdb_pb2.TabularData = None

    def set_datafeed(self, datafeed: str):
        self.datafeed = datafeed
        return self

    def set_tabular_data(self, tabular_data: tsdb_pb2.TabularData):
        self.tabular_data = tabular_data
        return self

    def build(self):
        ret = tsdb_pb2.PutDataRequest(datafeed=self.datafeed, data=self.tabular_data)
        return ret


class OutputColumnBuilder(object):

    def __init__(self):
        self.expr: str = None
        self.alias: str = None

    def set_expr(self, expr: str):
        self.expr = expr
        return self

    def set_alias(self, alias: str):
        self.alias = alias
        return self

    def build(self):
        ret = tsdb_pb2.OutputColumn(expr=self.expr, alias=self.alias)
        return ret


class GetDataRequestBuilder(object):

    def __init__(self, datafeed: str = None, column: tsdb_pb2.OutputColumn = None, where: str = None,
                 group_by: str = None, having: str = None, order_by: str = None, offset: int = 0, limit: int = 100, distinct: bool = False):
        self.datafeed = datafeed
        self.column = [] if column is None else column
        self.where = where
        self.group_by = group_by
        self.having = having
        self.order_by = order_by
        self.offset = offset
        self.limit = limit
        self.distinct = distinct

    def set_datafeed(self, datafeed: str = None):
        self.datafeed = datafeed
        return self

    def add_column(self, column: tsdb_pb2.OutputColumn = None):
        self.column.append(column)
        return self

    def set_where(self, where: str = None):
        self.where = where
        return self

    def set_group_by(self, group_by: str = None):
        self.group_by = group_by
        return self

    def set_having(self, having: str = None):
        self.having = having
        return self

    def set_order_by(self, order_by: str = None):
        self.order_by = order_by
        return self

    def set_offset(self, offset: int = None):
        self.offset = offset
        return self

    def set_limit(self, limit: int = None):
        self.limit = limit
        return self

    def set_distinct(self, distinct: bool = None):
        self.distinct = distinct
        return self

    def add_arg(self, argument: tsdb_pb2.Val = None):
        self.args.append(argument)
        return self

    def build(self) -> tsdb_pb2.GetDataRequest:
        ret = tsdb_pb2.GetDataRequest(datafeed=self.datafeed, column=self.column, where=self.where,
                                      groupBy=self.group_by, having=self.having, orderBy=self.order_by,
                                      offset=self.offset, limit=self.limit, distinct=self.distinct)
        return ret



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: apeman/dal/tsdb/tsdb.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1a\x61peman/dal/tsdb/tsdb.proto\x12\x0e\x63om.apeman.dal\"\x88\x01\n\x10\x43olumnDefinition\x12\x0c\n\x04name\x18\x01 \x01(\t\x12&\n\x04type\x18\x02 \x01(\x0e\x32\x18.com.apeman.dal.DataType\x12\x12\n\x05limit\x18\x03 \x01(\x05H\x00\x88\x01\x01\x12\x14\n\x07nonNull\x18\x04 \x01(\x08H\x01\x88\x01\x01\x42\x08\n\x06_limitB\n\n\x08_nonNull\"\x19\n\tUniqueKey\x12\x0c\n\x04name\x18\x01 \x03(\t\"\xf7\x01\n\x15\x43reateDatafeedRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12-\n\x03tag\x18\x02 \x03(\x0b\x32 .com.apeman.dal.ColumnDefinition\x12/\n\x05\x66ield\x18\x03 \x03(\x0b\x32 .com.apeman.dal.ColumnDefinition\x12,\n\tuniqueKey\x18\x04 \x03(\x0b\x32\x19.com.apeman.dal.UniqueKey\x12\x33\n\ndataAmount\x18\x05 \x01(\x0e\x32\x1a.com.apeman.dal.DataAmountH\x00\x88\x01\x01\x42\r\n\x0b_dataAmount\"\x18\n\x16\x43reateDatafeedResponse\"\"\n\tTimestamp\x12\x15\n\repochInMillis\x18\x01 \x01(\x03\"\x87\x01\n\x03Val\x12\x0b\n\x01s\x18\x01 \x01(\tH\x00\x12\r\n\x03i64\x18\x02 \x01(\x03H\x00\x12\r\n\x03i32\x18\x03 \x01(\x05H\x00\x12\x0b\n\x01\x64\x18\x04 \x01(\x01H\x00\x12\x0b\n\x01\x66\x18\x05 \x01(\x02H\x00\x12\x0b\n\x01\x62\x18\x06 \x01(\x08H\x00\x12\'\n\x02ts\x18\x07 \x01(\x0b\x32\x19.com.apeman.dal.TimestampH\x00\x42\x05\n\x03Val\"B\n\nColumnMeta\x12\x0c\n\x04name\x18\x01 \x01(\t\x12&\n\x04type\x18\x02 \x01(\x0e\x32\x18.com.apeman.dal.DataType\"*\n\x05Tuple\x12!\n\x04\x63\x65ll\x18\x01 \x03(\x0b\x32\x13.com.apeman.dal.Val\"_\n\x0bTabularData\x12*\n\x06\x63olumn\x18\x01 \x03(\x0b\x32\x1a.com.apeman.dal.ColumnMeta\x12$\n\x05tuple\x18\x02 \x03(\x0b\x32\x15.com.apeman.dal.Tuple\"M\n\x0ePutDataRequest\x12\x10\n\x08\x64\x61tafeed\x18\x01 \x01(\t\x12)\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1b.com.apeman.dal.TabularData\"\x11\n\x0fPutDataResponse\":\n\x0cOutputColumn\x12\x0c\n\x04\x65xpr\x18\x01 \x01(\t\x12\x12\n\x05\x61lias\x18\x02 \x01(\tH\x00\x88\x01\x01\x42\x08\n\x06_alias\"\xd7\x02\n\x0eGetDataRequest\x12\x10\n\x08\x64\x61tafeed\x18\x01 \x01(\t\x12,\n\x06\x63olumn\x18\x02 \x03(\x0b\x32\x1c.com.apeman.dal.OutputColumn\x12\x12\n\x05where\x18\x03 \x01(\tH\x00\x88\x01\x01\x12\x14\n\x07groupBy\x18\x04 \x01(\tH\x01\x88\x01\x01\x12\x13\n\x06having\x18\x05 \x01(\tH\x02\x88\x01\x01\x12\x14\n\x07orderBy\x18\x06 \x01(\tH\x03\x88\x01\x01\x12\x13\n\x06offset\x18\x07 \x01(\x03H\x04\x88\x01\x01\x12\x12\n\x05limit\x18\x08 \x01(\x03H\x05\x88\x01\x01\x12!\n\x04\x61rgs\x18\t \x03(\x0b\x32\x13.com.apeman.dal.Val\x12\x15\n\x08\x64istinct\x18\n \x01(\x08H\x06\x88\x01\x01\x42\x08\n\x06_whereB\n\n\x08_groupByB\t\n\x07_havingB\n\n\x08_orderByB\t\n\x07_offsetB\x08\n\x06_limitB\x0b\n\t_distinct\"N\n\x0fGetDataResponse\x12\x10\n\x08\x64\x61tafeed\x18\x01 \x01(\t\x12)\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1b.com.apeman.dal.TabularData\")\n\x15\x44\x65leteDatafeedRequest\x12\x10\n\x08\x64\x61tafeed\x18\x01 \x01(\t\"\x18\n\x16\x44\x65leteDatafeedResponse\"5\n\x13ListDatafeedRequest\x12\x13\n\x06\x66ilter\x18\x01 \x01(\tH\x00\x88\x01\x01\x42\t\n\x07_filter\"\x90\x02\n\x0e\x44\x61tafeedResult\x12\x10\n\x08\x64\x61tafeed\x18\x01 \x01(\t\x12-\n\x03tag\x18\x02 \x03(\x0b\x32 .com.apeman.dal.ColumnDefinition\x12/\n\x05\x66ield\x18\x03 \x03(\x0b\x32 .com.apeman.dal.ColumnDefinition\x12,\n\tuniqueKey\x18\x04 \x03(\x0b\x32\x19.com.apeman.dal.UniqueKey\x12.\n\ndataAmount\x18\x05 \x03(\x0e\x32\x1a.com.apeman.dal.DataAmount\x12.\n\x0b\x63reatedTime\x18\x06 \x03(\x0b\x32\x19.com.apeman.dal.Timestamp\"H\n\x14ListDatafeedResponse\x12\x30\n\x08\x64\x61tafeed\x18\x01 \x03(\x0b\x32\x1e.com.apeman.dal.DatafeedResult\"&\n\x12GetDatafeedRequest\x12\x10\n\x08\x64\x61tafeed\x18\x01 \x01(\t\"Y\n\x13GetDatafeedResponse\x12\x35\n\x08\x64\x61tafeed\x18\x01 \x01(\x0b\x32\x1e.com.apeman.dal.DatafeedResultH\x00\x88\x01\x01\x42\x0b\n\t_datafeed\"\x1c\n\x0cResultAsJson\x12\x0c\n\x04json\x18\x01 \x01(\t*d\n\x08\x44\x61taType\x12\x10\n\x0cUNKNOWN_TYPE\x10\x00\x12\x08\n\x04TEXT\x10\x01\x12\x08\n\x04UUID\x10\x02\x12\r\n\tTIMESTAMP\x10\x03\x12\n\n\x06\x42IGINT\x10\x04\x12\x0b\n\x07\x42OOLEAN\x10\x05\x12\n\n\x06\x44OUBLE\x10\x06*@\n\nDataAmount\x12\x12\n\x0eUNKNOWN_AMOUNT\x10\x00\x12\t\n\x05SMALL\x10\x01\x12\n\n\x06MEDIUM\x10\x02\x12\x07\n\x03\x42IG\x10\x03\x32\xe9\x04\n\x0bTsdbService\x12_\n\x0e\x63reateDatafeed\x12%.com.apeman.dal.CreateDatafeedRequest\x1a&.com.apeman.dal.CreateDatafeedResponse\x12_\n\x0e\x64\x65leteDatafeed\x12%.com.apeman.dal.DeleteDatafeedRequest\x1a&.com.apeman.dal.DeleteDatafeedResponse\x12V\n\x0bgetDatafeed\x12\".com.apeman.dal.GetDatafeedRequest\x1a#.com.apeman.dal.GetDatafeedResponse\x12Y\n\x0clistDatafeed\x12#.com.apeman.dal.ListDatafeedRequest\x1a$.com.apeman.dal.ListDatafeedResponse\x12J\n\x07putData\x12\x1e.com.apeman.dal.PutDataRequest\x1a\x1f.com.apeman.dal.PutDataResponse\x12J\n\x07getData\x12\x1e.com.apeman.dal.GetDataRequest\x1a\x1f.com.apeman.dal.GetDataResponse\x12M\n\rgetDataAsJson\x12\x1e.com.apeman.dal.GetDataRequest\x1a\x1c.com.apeman.dal.ResultAsJsonB\x12\n\x0e\x63om.apeman.dalP\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'apeman.dal.tsdb.tsdb_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\016com.apeman.dalP\001'
  _DATATYPE._serialized_start=2089
  _DATATYPE._serialized_end=2189
  _DATAAMOUNT._serialized_start=2191
  _DATAAMOUNT._serialized_end=2255
  _COLUMNDEFINITION._serialized_start=47
  _COLUMNDEFINITION._serialized_end=183
  _UNIQUEKEY._serialized_start=185
  _UNIQUEKEY._serialized_end=210
  _CREATEDATAFEEDREQUEST._serialized_start=213
  _CREATEDATAFEEDREQUEST._serialized_end=460
  _CREATEDATAFEEDRESPONSE._serialized_start=462
  _CREATEDATAFEEDRESPONSE._serialized_end=486
  _TIMESTAMP._serialized_start=488
  _TIMESTAMP._serialized_end=522
  _VAL._serialized_start=525
  _VAL._serialized_end=660
  _COLUMNMETA._serialized_start=662
  _COLUMNMETA._serialized_end=728
  _TUPLE._serialized_start=730
  _TUPLE._serialized_end=772
  _TABULARDATA._serialized_start=774
  _TABULARDATA._serialized_end=869
  _PUTDATAREQUEST._serialized_start=871
  _PUTDATAREQUEST._serialized_end=948
  _PUTDATARESPONSE._serialized_start=950
  _PUTDATARESPONSE._serialized_end=967
  _OUTPUTCOLUMN._serialized_start=969
  _OUTPUTCOLUMN._serialized_end=1027
  _GETDATAREQUEST._serialized_start=1030
  _GETDATAREQUEST._serialized_end=1373
  _GETDATARESPONSE._serialized_start=1375
  _GETDATARESPONSE._serialized_end=1453
  _DELETEDATAFEEDREQUEST._serialized_start=1455
  _DELETEDATAFEEDREQUEST._serialized_end=1496
  _DELETEDATAFEEDRESPONSE._serialized_start=1498
  _DELETEDATAFEEDRESPONSE._serialized_end=1522
  _LISTDATAFEEDREQUEST._serialized_start=1524
  _LISTDATAFEEDREQUEST._serialized_end=1577
  _DATAFEEDRESULT._serialized_start=1580
  _DATAFEEDRESULT._serialized_end=1852
  _LISTDATAFEEDRESPONSE._serialized_start=1854
  _LISTDATAFEEDRESPONSE._serialized_end=1926
  _GETDATAFEEDREQUEST._serialized_start=1928
  _GETDATAFEEDREQUEST._serialized_end=1966
  _GETDATAFEEDRESPONSE._serialized_start=1968
  _GETDATAFEEDRESPONSE._serialized_end=2057
  _RESULTASJSON._serialized_start=2059
  _RESULTASJSON._serialized_end=2087
  _TSDBSERVICE._serialized_start=2258
  _TSDBSERVICE._serialized_end=2875
# @@protoc_insertion_point(module_scope)



import time

from apeman.dal.tsdb import ColumnDefinitionBuilder, CreateDatafeedRequestBuilder, \
    UniqueKeyBuilder
from apeman.dal.tsdb import DataAmount
from apeman.dal.tsdb import DataType
from apeman.dal.tsdb import tsdb_client
from apeman.dal.tsdb import tsdb_pb2
from apeman.dal.tsdb.proto_builder import TabularDataBuilder, ColumnMetaBuilder, TupleBuilder, ValBuilder, \
    DataAmountBuilder, DataTypeBuilder, TimestampBuilder, PutDataRequestBuilder, OutputColumnBuilder, \
    GetDataRequestBuilder

print(tsdb_client)
test_val = ValBuilder().set_ts(epoch_in_millis=int(time.time() * 1000)).build()
print(test_val)
# build create datafeed request
tag = ColumnDefinitionBuilder() \
    .set_name(name='tag_nae') \
    .set_non_null(non_null=True) \
    .set_type(data_type=DataType.TEXT) \
    .set_limit(limit=100).build()

field = ColumnDefinitionBuilder() \
    .set_name(name='field_name') \
    .set_non_null(non_null=True) \
    .set_type(data_type=DataType.TEXT) \
    .set_limit(limit=100).build()

data_type_builder = DataTypeBuilder().set_type(data_type=DataType.TEXT)
data_type = data_type_builder.build()

unique_key = UniqueKeyBuilder().add(name='tag_name').build()
unique_key_2 = UniqueKeyBuilder().add(name='field_name').build()

data_amount = DataAmountBuilder().set_data_amount(data_amount=DataAmount.SMALL).build()

create_datafeed_request = CreateDatafeedRequestBuilder() \
    .set_name(name='test') \
    .add_tag(tag=tag) \
    .add_field(field=field) \
    .add_unique_key(unique_key=unique_key) \
    .add_unique_key(unique_key=unique_key_2) \
    .set_data_amount(data_amount=DataAmount.SMALL) \
    .build()

column_a = ColumnMetaBuilder() \
    .set_name(name='column_a') \
    .set_data_type(data_type=DataType.TEXT) \
    .build()
column_b = ColumnMetaBuilder() \
    .set_name(name='column_b') \
    .set_data_type(data_type=DataType.BIGINT) \
    .build()

tuple_a = TupleBuilder() \
    .add_val(val=ValBuilder().set_i32(1000).build()) \
    .add_val(val=ValBuilder().set_i32(1000).build()) \
    .add_val(val=ValBuilder().set_i32(1000).build()) \
    .add_val(val=ValBuilder().set_i32(1000).build()) \
    .build()

tuple_b = TupleBuilder() \
    .add_val(val=ValBuilder().set_i32(1000).build()) \
    .add_val(val=ValBuilder().set_i32(1000).build()) \
    .add_val(val=ValBuilder().set_i32(1000).build()) \
    .add_val(val=ValBuilder().set_i32(1000).build()) \
    .build()

data = TabularDataBuilder() \
    .add_column(column=column_a) \
    .add_column(column=column_b) \
    .add_tuple(t=tuple_a) \
    .add_tuple(t=tuple_b) \
    .build()

ts_builder = TimestampBuilder().set_epoch_in_millis(epoch_in_millis=1000)
ts = ts_builder.build()

put_data_request_builder = PutDataRequestBuilder().set_datafeed(datafeed='test').set_tabular_data(tabular_data=data)
put_data_request = put_data_request_builder.build()

output_column1 = GetDataRequestBuilder()
output_column2 = GetDataRequestBuilder()
output_column3 = GetDataRequestBuilder()

output_column = OutputColumnBuilder().set_expr(expr='test1').set_alias(alias='test1').build()
get_data_request = GetDataRequestBuilder() \
    .add_column(column=output_column) \
    .set_datafeed(datafeed='test') \
    .set_where(where='') \
    .set_group_by(group_by='') \
    .set_having(having='') \
    .set_order_by(order_by='') \
    .set_offset(offset=0) \
    .set_limit(limit=100) \
    .set_distinct(distinct=False) \
    .build()
print(get_data_request)

output_column2 = OutputColumnBuilder().set_expr(expr='test2').set_alias(alias='test2').build()
get_data_request2 = GetDataRequestBuilder() \
    .add_column(column=output_column2) \
    .set_datafeed(datafeed='test') \
    .set_where(where='') \
    .set_group_by(group_by='') \
    .set_having(having='') \
    .set_order_by(order_by='') \
    .set_offset(offset=0) \
    .set_limit(limit=100) \
    .set_distinct(distinct=False) \
    .build()

print(get_data_request2)

data_type = tsdb_pb2.DataType.Value('TEXT')
print(data_type)



import logging
import os

import grpc

from apeman.dal.tsdb import tsdb_pb2
from apeman.dal.tsdb import tsdb_pb2_grpc

logger = logging.getLogger("apeman.tsdb.client")


class ApemanDalTsdbClient(object):

    def __init__(self):
        apeman_dal_server_addr = os.getenv("apeman_dal_server_addr")
        if apeman_dal_server_addr is None:
            raise RuntimeError('Invalid value of apeman_dal_server_addr')

        logging.info('Connect to APEMAN DAL server %s', apeman_dal_server_addr)
        channel = grpc.insecure_channel(apeman_dal_server_addr)
        self.__stub = tsdb_pb2_grpc.TsdbServiceStub(channel)

    def create_datafeed(self, request=None):
        try:
            self.__stub.createDatafeed(request=request)
        except grpc.RpcError as e:
            logger.error(e)
            logger.error(e.args[0].trailing_metadata)
            raise Exception(e.details(), e.args[0].trailing_metadata)

    def delete_datafeed(self, datafeed=''):
        request = tsdb_pb2.DeleteDatafeedRequest(datafeed=datafeed)
        try:
            self.__stub.deleteDatafeed(request=request)
        except grpc.RpcError as e:
            logger.error(e)
            logger.error(e.args[0].trailing_metadata)
            raise Exception(e.details(), e.args[0].trailing_metadata)

    def get_datafeed(self, datafeed=''):
        request = tsdb_pb2.GetDatafeedRequest(datafeed=datafeed)
        try:
            return self.__stub.getDatafeed(request=request)
        except grpc.RpcError as e:
            logger.error(e)
            logger.error(e.args[0].trailing_metadata)
            raise Exception(e.details(), e.args[0].trailing_metadata)

    def list_datafeed(self, query_filter=''):
        request = tsdb_pb2.ListDatafeedRequest(filter=query_filter)
        try:
            return self.__stub.listDatafeed(request=request)
        except grpc.RpcError as e:
            logger.error(e)
            logger.error(e.args[0].trailing_metadata)
            raise Exception(e.details(), e.args[0].trailing_metadata)

    def put_data(self, datafeed='', data=None):
        request = tsdb_pb2.PutDataRequest(datafeed=datafeed, data=data)
        try:
            self.__stub.putData(request=request)
        except grpc.RpcError as e:
            logger.error(e)
            logger.error(e.args[0].trailing_metadata)
            raise Exception(e.details(), e.args[0].trailing_metadata)

    def get_data(self, request=None):
        try:
            return self.__stub.getData(request=request)
        except grpc.RpcError as e:
            logger.error(e)
            logger.error(e.args[0].trailing_metadata)
            raise Exception(e.details(), e.args[0].trailing_metadata)

    def get_data_as_json(self, request: tsdb_pb2.GetDataRequest = None):
        try:
            return self.__stub.getDataAsJson(request=request)
        except grpc.RpcError as e:
            logger.error(e)
            logger.error(e.args[0].trailing_metadata)
            raise Exception(e.details(), e.args[0].trailing_metadata)



from apeman.dal.tsdb.data_amount import DataAmount
from apeman.dal.tsdb.data_type import DataType
from apeman.dal.tsdb.proto_builder import DataTypeBuilder, DataAmountBuilder, UniqueKeyBuilder, TimestampBuilder, \
    TabularDataBuilder, \
    TupleBuilder, ValBuilder, GetDataRequestBuilder, CreateDatafeedRequestBuilder, ColumnDefinitionBuilder, \
    ColumnMetaBuilder, OutputColumnBuilder
from apeman.dal.tsdb.tsdb_client import ApemanDalTsdbClient

tsdb_client = ApemanDalTsdbClient()



from enum import Enum


class DataType(Enum):
    UNKNOWN = 'UNKNOWN'
    TEXT = 'TEXT'
    UUID = 'UUID'
    TIMESTAMP = 'TIMESTAMP'
    BIGINT = 'BIGINT'
    BOOLEAN = 'BOOLEAN'
    DOUBLE = 'DOUBLE'
